@@ -17,7 +17,8 @@
 
 #' Contour maps and contour map quality measures for latent Gaussian models
 #'
-#' \code{contourmap} is used for calculating contour maps and quality measures for contour maps for Gaussian models.
+#' `contourmap` is used for calculating contour maps and quality measures for
+#' contour maps for Gaussian models.
 #'
 #' @param mu Expectation vector.
 #' @param Q Precision matrix.
@@ -27,53 +28,63 @@
 #' @param levels Levels to use in contour map.
 #' @param type Type of contour map. One of:
 #' \describe{
-#'      \item{'standard' }{Equidistant levels between smallest and largest value of the posterior mean (default).}
-#'      \item{'pretty' }{Equally spaced 'round' values which cover the range of the values in the posterior mean.}
-#'      \item{'equalarea' }{Levels such that different spatial regions are approximately equal in size.}
+#'      \item{'standard' }{Equidistant levels between smallest and largest value
+#'        of the posterior mean (default).}
+#'      \item{'pretty' }{Equally spaced 'round' values which cover the range of
+#'        the values in the posterior mean.}
+#'      \item{'equalarea' }{Levels such that different spatial regions are
+#'        approximately equal in size.}
 #'      \item{'P0-optimal' }{Levels chosen to maximize the P0 measure.}
 #'      \item{'P1-optimal' }{Levels chosen to maximize the P1 measure.}
 #'      \item{'P2-optimal' }{Levels chosen to maximize the P2 measure.}
 #' }
 #' @param compute A list with quality indices to compute
 #' \describe{
-#'      \item{'F': }{TRUE/FALSE indicating whether the contour map function should be computed (default TRUE).}
-#'      \item{'measures': }{A list with the quality measures to compute ("P0", "P1", "P2") or corresponding bounds based only on the marginal probabilities ("P0-bound", "P1-bound", "P2-bound").}
+#'      \item{'F': }{TRUE/FALSE indicating whether the contour map function
+#'        should be computed (default TRUE).}
+#'      \item{'measures': }{A list with the quality measures to compute
+#'        ("P0", "P1", "P2") or corresponding bounds based only on the marginal
+#'        probabilities ("P0-bound", "P1-bound", "P2-bound").}
 #'      }
-#' @param use.marginals Only marginal distributions are used when finding P-optimal maps (default TRUE).
+#' @param use.marginals Only marginal distributions are used when finding
+#'   P-optimal maps (default TRUE).
 #' @param alpha Maximal error probability in contour map function (default=1).
-#' @param F.limit The limit value for the computation of the F function. F is set to NA for all nodes where F<1-F.limit. Default is F.limit = \code{alpha}.
-#' @param n.iter Number or iterations in the MC sampler that is used for calculating the quantities in \code{compute}. The default value is 10000.
+#' @param F.limit The limit value for the computation of the F function. F is
+#'   set to NA for all nodes where `F < 1-F.limit`. Default is `F.limit = alpha`.
+#' @param n.iter Number or iterations in the MC sampler that is used for
+#'   calculating the quantities in `compute`. The default value is 10000.
 #' @param verbose Set to TRUE for verbose mode (optional).
-#' @param max.threads Decides the number of threads the program can use. Set to 0 for using the maximum number of threads allowed by the system (default).
+#' @param max.threads Decides the number of threads the program can use. Set to
+#'   0 for using the maximum number of threads allowed by the system (default).
 #' @param seed Random seed (optional).
 #'
-#' @return \code{contourmap} returns an object of class "excurobj" with the following elements
+#' @return `contourmap` returns an object of class "excurobj" with the following elements
 #'     \item{u }{Contour levels used in the contour map.}
 #'     \item{n.levels }{The number of contours used.}
 #'     \item{u.e }{The values associated with the level sets G_k.}
 #'     \item{G }{A vector which shows which of the level sets G_k each node belongs to.}
-#'     \item{map }{Representation of the contour map with map[i]=u.e[k] if i is in G_k.}
+#'     \item{map }{Representation of the contour map with `map[i]=u.e[k]` if i is in `G_k`.}
 #'     \item{F }{The contour map function (if computed).}
-#'     \item{M }{Contour avoiding sets (if \code{F} is computed). \eqn{M=-1} for all non-significant nodes and  \eqn{M=k} for nodes that belong to \eqn{M_k}.}
+#'     \item{M }{Contour avoiding sets (if `F` is computed). \eqn{M=-1} for all non-significant nodes and  \eqn{M=k} for nodes that belong to \eqn{M_k}.}
 #'     \item{P0/P1/P2 }{Calculated quality measures (if computed).}
 #'     \item{P0bound/P1bound/P2bound }{Calculated upper bounds quality measures (if computed).}
 #'     \item{meta }{A list containing various information about the calculation.}
 #' @export
 #' @details
-#' The Gaussian model is specified using the mean \code{mu} and the precision matrix
-#' \code{Q}. The contour map is then computed for the mean, using either the contour
-#' levels specified in \code{levels}, or \code{n.levels} contours that are placed according
-#' to the argument \code{type}.
+#' The Gaussian model is specified using the mean `mu` and the precision matrix
+#' `Q`. The contour map is then computed for the mean, using either the contour
+#' levels specified in `levels`, or `n.levels` contours that are placed according
+#' to the argument `type`.
 #'
 #' A number of quality measures can be computed based based on the specified contour map
 #' and the Gaussian distribution. What should be computed is specified using the
-#' \code{compute} argument. For details on these quanties, see the reference below.
+#' `compute` argument. For details on these quanties, see the reference below.
 #'
 #' @author David Bolin \email{davidbolin@@gmail.com}
-#' @references Bolin, D. and Lindgren, F. (2017) \emph{Quantifying the uncertainty of contour maps}, Journal of Computational and Graphical Statistics, vol 26, no 3, pp 513-524.
+#' @references Bolin, D. and Lindgren, F. (2017) *Quantifying the uncertainty of contour maps*, Journal of Computational and Graphical Statistics, vol 26, no 3, pp 513-524.
 #'
-#' Bolin, D. and Lindgren, F. (2018), \emph{Calculating Probabilistic Excursion Sets and Related Quantities Using excursions}, Journal of Statistical Software, vol 86, no 1, pp 1-20.
-#' @seealso \code{\link{contourmap.inla}}, \code{\link{contourmap.mc}}, \code{\link{contourmap.colors}}
+#' Bolin, D. and Lindgren, F. (2018), *Calculating Probabilistic Excursion Sets and Related Quantities Using excursions*, Journal of Statistical Software, vol 86, no 1, pp 1-20.
+#' @seealso [contourmap.inla()], [contourmap.mc()], [contourmap.colors()]
 #' @examples
 #' n <- 10
 #' Q <- Matrix(toeplitz(c(1, -0.5, rep(0, n - 2))))
@@ -221,8 +232,16 @@ contourmap <- function(mu,
       if (measure[i] == "P1") {
         if (n.levels > 1) {
           if (verbose) cat("Calculating P1-measure\n")
-          tmp <- Pmeasure(lp = lp, mu = mu, Q = Q, ind = ind, type = 1, 
-                          seed = seed, n.iter = n.iter, max.threads = max.threads)
+          tmp <- Pmeasure(
+            lp = lp,
+            mu = mu,
+            Q = Q,
+            ind = ind,
+            type = 1,
+            seed = seed,
+            n.iter = n.iter,
+            max.threads = max.threads
+          )
           lp$P1 <- tmp$P
           lp$P1.error <- tmp$E
         } else {
@@ -231,8 +250,16 @@ contourmap <- function(mu,
         }
       } else if (measure[i] == "P2") {
         if (verbose) cat("Calculating P2-measure\n")
-        tmp <- Pmeasure(lp = lp, mu = mu, Q = Q, ind = ind, type = 2, 
-                        seed = seed, n.iter = n.iter, max.threads = max.threads)
+        tmp <- Pmeasure(
+          lp = lp,
+          mu = mu,
+          Q = Q,
+          ind = ind,
+          type = 2,
+          seed = seed,
+          n.iter = n.iter,
+          max.threads = max.threads
+        )
         lp$P2 <- tmp$P
         lp$P2.error <- tmp$E
       } else if (measure[i] == "P0") {
