@@ -14,18 +14,16 @@ contourfunction.mc <- function(lp, mu, X, ind, alpha, verbose = FALSE) {
 
   lim <- excursions.limits(lp = lp, mu = mu, measure = 0)
 
-  m.size <- length(mu)
-  indices <- NULL
-
-  if (!missing(ind)) {
-    if (is.logical(ind)) {
-      indices <- ind
-      m.size <- sum(ind)
-    } else {
-      indices <- rep(FALSE, length(mu))
-      indices[ind] <- TRUE
-      m.size <- length(ind)
-    }
+  if (missing(ind)) {
+    indices <- NULL
+    # m.size <- length(mu)
+  } else if (is.logical(ind)) {
+    indices <- ind
+    # m.size <- sum(ind)
+  } else {
+    indices <- rep(FALSE, length(mu))
+    indices[ind] <- TRUE
+    # m.size <- length(ind)
   }
   if (verbose) cat("calculate marginals\n")
 
@@ -42,23 +40,23 @@ contourfunction.mc <- function(lp, mu, X, ind, alpha, verbose = FALSE) {
   ii <- which(res$Pv[1:n] > 0)
   if (length(ii) == 0) i <- n + 1 else i <- min(ii)
 
-  F <- Fe <- E <- rep(0, n)
-  F[reo] <- res$Pv
+  F_ <- Fe <- E <- rep(0, n)
+  F_[reo] <- res$Pv
   Fe[reo] <- res$Ev
 
   ireo <- NULL
   ireo[reo] <- 1:n
 
-  ind.lowF <- F < 1 - F.limit
-  E[F > 1 - alpha] <- 1
-  F[ind.lowF] <- Fe[ind.lowF] <- NA
+  ind.lowF <- F_ < 1 - F.limit
+  E[F_ > 1 - alpha] <- 1
+  F_[ind.lowF] <- Fe[ind.lowF] <- NA
 
   M <- rep(-1, n)
   for (i in 1:(lp$n.levels + 1)) {
     M[(lp$G == (i - 1)) & (E == 1)] <- i - 1
   }
 
-  return(list(F = F, Fe = Fe, E = E, M = M, rho = rho))
+  return(list(F = F_, Fe = Fe, E = E, M = M, rho = rho))
 }
 
 
@@ -108,18 +106,16 @@ contourfunction <- function(lp, mu, Q, vars, ind, alpha, n.iter = 10000,
     }
   }
 
-  m.size <- length(mu)
-  indices <- NULL
-
-  if (!missing(ind)) {
-    if (is.logical(ind)) {
-      indices <- ind
-      m.size <- sum(ind)
-    } else {
-      indices <- rep(FALSE, length(mu))
-      indices[ind] <- TRUE
-      m.size <- length(ind)
-    }
+  if (missing(ind)) {
+    indices <- NULL
+    m.size <- length(mu)
+  } else if (is.logical(ind)) {
+    indices <- ind
+    m.size <- sum(ind)
+  } else {
+    indices <- rep(FALSE, length(mu))
+    indices[ind] <- TRUE
+    m.size <- length(ind)
   }
   if (verbose) cat("calculate marginals\n")
   if (missing(rho) || is.null(rho)) {
@@ -152,23 +148,23 @@ contourfunction <- function(lp, mu, Q, vars, ind, alpha, n.iter = 10000,
   ii <- which(res$Pv[1:n] > 0)
   if (length(ii) == 0) i <- n + 1 else i <- min(ii)
 
-  F <- Fe <- E <- rep(0, n)
-  F[reo] <- res$Pv
+  F_ <- Fe <- E <- rep(0, n)
+  F_[reo] <- res$Pv
   Fe[reo] <- res$Ev
 
   ireo <- NULL
   ireo[reo] <- 1:n
 
-  ind.lowF <- F < 1 - F.limit
-  E[F > 1 - alpha] <- 1
-  F[ind.lowF] <- Fe[ind.lowF] <- NA
+  ind.lowF <- F_ < 1 - F.limit
+  E[F_ > 1 - alpha] <- 1
+  F_[ind.lowF] <- Fe[ind.lowF] <- NA
 
   M <- rep(-1, n)
   for (i in 1:(lp$n.levels + 1)) {
     M[(lp$G == (i - 1)) & (E == 1)] <- i - 1
   }
 
-  return(list(F = F, Fe = Fe, E = E, M = M, rho = rho))
+  return(list(F = F_, Fe = Fe, E = E, M = M, rho = rho))
 }
 
 ## Calculate marginal probabilities P(lim$a < X < lim$b) for
@@ -181,7 +177,8 @@ contourmap.marginals <- function(mu, vars, lim, ind) {
   } else {
     marg <- pnorm(lim$b, mu, sqrt(vars)) - pnorm(lim$a, mu, sqrt(vars))
   }
-  return(marg)
+
+  marg
 }
 
 ## Calculate marginal probabilities P(lim$a < X < lim$b) for
@@ -193,7 +190,8 @@ contourmap.marginals.mc <- function(X, lim, ind) {
   } else {
     marg <- rowMeans(lim$a < X & X < lim$b)
   }
-  return(marg)
+
+  marg
 }
 
 ## Create a levelplot with given levels/number of levels
@@ -276,7 +274,7 @@ excursions.levelplot <- function(mu, n.levels, ind, levels,
 
 ## Create a P-optimal levelplot.
 ## The function will take A LOT of time to run if use.marginals=FALSE.
-excursions.opt.levelplot <- function(mu, vars, Q, n.levels, measure = 2, 
+excursions.opt.levelplot <- function(mu, vars, Q, n.levels, measure = 2,
                                      use.marginals = TRUE, ind, max.threads = 0) {
   if ((measure != 1) && (measure != 2) && (measure != 0)) {
     stop("only measure 0, 1, or 2 allowed")
@@ -402,12 +400,14 @@ Pmeasure.bound <- function(lp, mu, vars, type, ind = NULL) {
 }
 
 ## Function that calculates the P measure for a given contour map.
-Pmeasure <- function(lp, mu, Q, Q.chol, ind = NULL, type, 
+Pmeasure <- function(lp, mu, Q, Q.chol, ind = NULL, type,
                      vars = vars, seed = NULL, n.iter = NULL,
                      max.threads = 0) {
   if (type == 0) {
-    res <- contourfunction(lp = lp, mu = mu, Q = Q, vars = vars, ind = ind,
-                            max.threads = max.threads)
+    res <- contourfunction(
+      lp = lp, mu = mu, Q = Q, vars = vars, ind = ind,
+      max.threads = max.threads
+    )
     p <- mean(res$F[ind])
   } else {
     if (type == 1 && length(lp$u) == 1) {
@@ -422,6 +422,8 @@ Pmeasure <- function(lp, mu, Q, Q.chol, ind = NULL, type,
     )
     p <- res$P[1]
   }
+  # TODO: Check if this should be P = p or P = res$P[1], as the 'p' values above
+  # are unused.
   return(list(P = res$P[1], E = res$E[1]))
 }
 
@@ -487,14 +489,15 @@ excursions.limits <- function(lp, mu, measure) {
   } else {
     stop("Measure must be 0, 1, or 2")
   }
-  return(list(a = a, b = b))
+
+  list(a = a, b = b)
 }
 
 #' Define a color map for displaying contour maps.
 #'
-#' \code{contourmap.colors} calculates suitable colours for displaying contour maps.
+#' `contourmap.colors` calculates suitable colours for displaying contour maps.
 #'
-#' @param lp A contourmap calculated by \code{contourmap}, \code{contourmap.inla}, or \code{contourmap.mc}
+#' @param lp A contourmap calculated by `contourmap`, `contourmap.inla`, or `contourmap.mc`
 #' @param zlim The range that should be used (optional). The default is the range of the mean value function used when creating the contourmap.
 #' @param col The colormap that the colours should be taken from.
 #' @param credible.col The color that should be used for displaying the credible regions for the contour curves (optional).
@@ -531,5 +534,5 @@ contourmap.colors <- function(lp, zlim, col, credible.col) {
     cmap <- c(credible.col, cmap)
   }
 
-  return(cmap)
+  cmap
 }
