@@ -8,7 +8,7 @@ using namespace std;
 extern "C" void reordering(int * nin, int * Mp, int * Mi, int * reo, int * cind)
 {
   int n = nin[0];
-  int status = camd_order(n,Mp,Mi,reo,(double *) NULL, (double *) NULL, cind);
+  camd_order(n,Mp,Mi,reo,(double *) NULL, (double *) NULL, cind);
 }
 
 				
